@@ -100,9 +100,6 @@ class PlywoodVariable(PlywoodValue):
     def get_name(self):
         return self.name
 
-    def set_id(self, scope, var):
-        return self.get_value(scope).set_id(scope, var)
-
     def python_value(self, scope):
         return self.get_value(scope).python_value(scope)
 
@@ -116,7 +113,7 @@ class PlywoodVariable(PlywoodValue):
             return retval
         except KeyError:
             line_no, line = this_line(scope['__input'], self.location)
-            raise PlywoodKeyError(self.name, line_no, line)
+            raise PlywoodKeyError(self.name, scope, scope['__input'])
 
     def get_attr(self, scope, right):
         return self.get_value(scope).get_attr(scope, right)
@@ -187,6 +184,11 @@ class PlywoodString(PlywoodValue):
         consuming = False
         was_close_bracket = False
         inside = ''
+        runtime = PlywoodEnv({'separator': ' '})
+        context = scope.get('self', {})
+        print("""=============== values.py at line {0} ===============
+context: {1!r}
+""".format(__import__('sys')._getframe().f_lineno - 2, context, ))
         while index < len(original):
             c = original[index]
             if consuming and was_close_bracket and c == '}':
@@ -194,9 +196,8 @@ class PlywoodString(PlywoodValue):
                 was_close_bracket = False
                 inside = PlywoodString.unindent(inside)
                 old_input = scope.get('__input', '')
-                runtime = PlywoodEnv({'separator': ' '}, scope)
                 scope['__input'] = inside
-                retval += Plywood(inside).run(runtime).rstrip()
+                retval += Plywood(inside).run(context, runtime).rstrip()
                 scope['__input'] = old_input
                 inside = ''
             elif consuming and c == '}':
@@ -325,7 +326,7 @@ class PlywoodOperator(PlywoodValue):
         op = str(self.operator)
         if self.operator == '[]':
             return '{self.left}[{self.right}]'.format(self=self)
-        if self.operator not in ['.', '@']:
+        if self.operator not in ['.']:
             op = ' ' + op + ' '
         return '{self.left}{op}{self.right}'.format(self=self, op=op)
 
@@ -370,16 +371,16 @@ class PlywoodUnaryOperator(PlywoodValue):
     OPERATORS = {}
 
     @classmethod
-    def register(cls, operator):
+    def register(cls, operator, **kwargs):
         def decorator(fn):
-            cls.OPERATORS[operator] = fn
+            cls.OPERATORS[operator] = (fn, kwargs)
             return fn
         return decorator
 
     @classmethod
     def handle(cls, operator, value, scope):
         try:
-            handler = cls.OPERATORS[operator.operator]
+            handler, _ = cls.OPERATORS[operator.operator]
         except KeyError:
             raise Exception('No operator handler for {operator!r}'.format(self=operator))
         return PlywoodWrapper(operator.location, handler(value, scope))
@@ -605,15 +606,13 @@ class PlywoodRuntime(PlywoodCallable):
 class PlywoodHtmlPlugin(PlywoodCallable):
     def __init__(self, fn):
         self.fn = fn
-        self.id = None
         self.classes = []
 
     def call(self, states, scope, arguments, block):
-        return [Continue()], PlywoodWrapper(self.location, self.fn(scope, arguments, block, self.classes, self.id))
+        return [Continue()], PlywoodWrapper(self.location, self.fn(scope, arguments, block, self.classes))
 
     def copy(self):
         copy = type(self)(self.fn)
-        copy.id = self.id
         copy.classes.extend(self.classes)
         if hasattr(self, 'location'):
             copy.location = self.location
@@ -624,11 +623,6 @@ class PlywoodHtmlPlugin(PlywoodCallable):
         copy.classes.append(right.get_name())
         return copy
 
-    def set_id(self, scope, var):
-        copy = self.copy()
-        copy.id = var.get_name()
-        return copy
-
 
 class PlywoodFunction(PlywoodCallable):
     def __init__(self, fn, accepts_block=False):
